searchNodes=[{"doc":"ErrorMessage This library exists to simplify error systems in a code base and allow for a simple unified experience when using and reading error messages around the code base This creates one standard, that all errors should fit into the context of HTTP error codes, if they don't :internal_server_error should be used and you can use the message and details to provide a further level of depth Installation The package can be installed by adding error_message to your list of dependencies in mix.exs : def deps do [ { :error_message , &quot;~&gt; 0.2.0&quot; } ] end Documentation can be found at https://hexdocs.pm/error_message . Usage Example iex&gt; id = 1 iex&gt; ErrorMessage . not_found ( &quot;no user with id \#{ id } &quot; , %{ user_id : id } ) % ErrorMessage { code : :not_found , message : &quot;no user with id 1&quot; , details : %{ user_id : 1 } } iex&gt; ErrorMessage . internal_server_error ( &quot;critical internal error&quot; , %{ ...&gt; reason : :massive_issue_with_x ...&gt; } ) % ErrorMessage { code : :internal_server_error , message : &quot;critical internal error&quot; , details : %{ reason : :massive_issue_with_x } } Why is this important If we want to have a good way to catch errors around our system as well as be able to display errors that happen throughout our system, it's useful to have a common error api so we can predict what will come out of a system For example if we used elixir through our server, we would be able to catch a not found pretty easily since we can predict the error code coming in without needing to know the message. This leads to more resilliant code since message changes won't break the functionality of your application # Because our error system is setup with `find_user` we can easily # catch no users and have a solid backup plan with { :error , % ErrorMessage { code : :not_found } } &lt;- find_user ( %{ name : &quot;bill&quot; } ) do create_user ( %{ name : &quot;bill&quot; } ) end Usage with Phoenix Another benefit is error rendering to the frontend, because all our errors are part of the HTTP error system, it's quite easy to now return the proper status codes and messages to our frontend clients. For example: defmodule MyController do def index ( conn , param ) do case find_thing ( params ) do { :ok , res } -&gt; json ( conn , res ) { :error , e } -&gt; json_error ( conn , e ) end end defp json_error ( conn , % ErrorMessage { code : code } = e ) do conn |&gt; put_status ( code ) # Plug.Conn |&gt; json ( ErrorMessage . to_jsonable_map ( e ) ) end end This will also add a request_id from Logger.metadata[:request_id] when found Usage with Logger Ontop of being useful for Phoenix we can also find some good use from this system and Logger, since ErrorMessage implements String.Chars protocol case do_thing ( ) do { :ok , value } -&gt; { :ok , do_other_thing ( value ) } { :error , e } = res -&gt; Logger . error ( &quot;[MyModule] \\# {e}&quot; ) Logger . warn ( to_string ( e ) ) res end","ref":"ErrorMessage.html","title":"ErrorMessage","type":"module"},{"doc":"Create bad_gateway error message for status code 502 Example iex&gt; ErrorMessage . bad_gateway ( &quot;error message&quot; ) % ErrorMessage { code : :bad_gateway , message : &quot;error message&quot; }","ref":"ErrorMessage.html#bad_gateway/1","title":"ErrorMessage.bad_gateway/1","type":"function"},{"doc":"Create bad_gateway error message for status code 502 with a details item which is passed in as the details key under the ErrorMessage struct Example iex&gt; ErrorMessage . bad_gateway ( &quot;error message&quot; , %{ item : 1234 } ) % ErrorMessage { code : :bad_gateway , message : &quot;error message&quot; , details : %{ item : 1234 } }","ref":"ErrorMessage.html#bad_gateway/2","title":"ErrorMessage.bad_gateway/2","type":"function"},{"doc":"Create bad_request error message for status code 400 Example iex&gt; ErrorMessage . bad_request ( &quot;error message&quot; ) % ErrorMessage { code : :bad_request , message : &quot;error message&quot; }","ref":"ErrorMessage.html#bad_request/1","title":"ErrorMessage.bad_request/1","type":"function"},{"doc":"Create bad_request error message for status code 400 with a details item which is passed in as the details key under the ErrorMessage struct Example iex&gt; ErrorMessage . bad_request ( &quot;error message&quot; , %{ item : 1234 } ) % ErrorMessage { code : :bad_request , message : &quot;error message&quot; , details : %{ item : 1234 } }","ref":"ErrorMessage.html#bad_request/2","title":"ErrorMessage.bad_request/2","type":"function"},{"doc":"Create conflict error message for status code 409 Example iex&gt; ErrorMessage . conflict ( &quot;error message&quot; ) % ErrorMessage { code : :conflict , message : &quot;error message&quot; }","ref":"ErrorMessage.html#conflict/1","title":"ErrorMessage.conflict/1","type":"function"},{"doc":"Create conflict error message for status code 409 with a details item which is passed in as the details key under the ErrorMessage struct Example iex&gt; ErrorMessage . conflict ( &quot;error message&quot; , %{ item : 1234 } ) % ErrorMessage { code : :conflict , message : &quot;error message&quot; , details : %{ item : 1234 } }","ref":"ErrorMessage.html#conflict/2","title":"ErrorMessage.conflict/2","type":"function"},{"doc":"Create expectation_failed error message for status code 417 Example iex&gt; ErrorMessage . expectation_failed ( &quot;error message&quot; ) % ErrorMessage { code : :expectation_failed , message : &quot;error message&quot; }","ref":"ErrorMessage.html#expectation_failed/1","title":"ErrorMessage.expectation_failed/1","type":"function"},{"doc":"Create expectation_failed error message for status code 417 with a details item which is passed in as the details key under the ErrorMessage struct Example iex&gt; ErrorMessage . expectation_failed ( &quot;error message&quot; , %{ item : 1234 } ) % ErrorMessage { code : :expectation_failed , message : &quot;error message&quot; , details : %{ item : 1234 } }","ref":"ErrorMessage.html#expectation_failed/2","title":"ErrorMessage.expectation_failed/2","type":"function"},{"doc":"Create failed_dependency error message for status code 424 Example iex&gt; ErrorMessage . failed_dependency ( &quot;error message&quot; ) % ErrorMessage { code : :failed_dependency , message : &quot;error message&quot; }","ref":"ErrorMessage.html#failed_dependency/1","title":"ErrorMessage.failed_dependency/1","type":"function"},{"doc":"Create failed_dependency error message for status code 424 with a details item which is passed in as the details key under the ErrorMessage struct Example iex&gt; ErrorMessage . failed_dependency ( &quot;error message&quot; , %{ item : 1234 } ) % ErrorMessage { code : :failed_dependency , message : &quot;error message&quot; , details : %{ item : 1234 } }","ref":"ErrorMessage.html#failed_dependency/2","title":"ErrorMessage.failed_dependency/2","type":"function"},{"doc":"Create forbidden error message for status code 403 Example iex&gt; ErrorMessage . forbidden ( &quot;error message&quot; ) % ErrorMessage { code : :forbidden , message : &quot;error message&quot; }","ref":"ErrorMessage.html#forbidden/1","title":"ErrorMessage.forbidden/1","type":"function"},{"doc":"Create forbidden error message for status code 403 with a details item which is passed in as the details key under the ErrorMessage struct Example iex&gt; ErrorMessage . forbidden ( &quot;error message&quot; , %{ item : 1234 } ) % ErrorMessage { code : :forbidden , message : &quot;error message&quot; , details : %{ item : 1234 } }","ref":"ErrorMessage.html#forbidden/2","title":"ErrorMessage.forbidden/2","type":"function"},{"doc":"Create found error message for status code 302 Example iex&gt; ErrorMessage . found ( &quot;error message&quot; ) % ErrorMessage { code : :found , message : &quot;error message&quot; }","ref":"ErrorMessage.html#found/1","title":"ErrorMessage.found/1","type":"function"},{"doc":"Create found error message for status code 302 with a details item which is passed in as the details key under the ErrorMessage struct Example iex&gt; ErrorMessage . found ( &quot;error message&quot; , %{ item : 1234 } ) % ErrorMessage { code : :found , message : &quot;error message&quot; , details : %{ item : 1234 } }","ref":"ErrorMessage.html#found/2","title":"ErrorMessage.found/2","type":"function"},{"doc":"Create gateway_timeout error message for status code 504 Example iex&gt; ErrorMessage . gateway_timeout ( &quot;error message&quot; ) % ErrorMessage { code : :gateway_timeout , message : &quot;error message&quot; }","ref":"ErrorMessage.html#gateway_timeout/1","title":"ErrorMessage.gateway_timeout/1","type":"function"},{"doc":"Create gateway_timeout error message for status code 504 with a details item which is passed in as the details key under the ErrorMessage struct Example iex&gt; ErrorMessage . gateway_timeout ( &quot;error message&quot; , %{ item : 1234 } ) % ErrorMessage { code : :gateway_timeout , message : &quot;error message&quot; , details : %{ item : 1234 } }","ref":"ErrorMessage.html#gateway_timeout/2","title":"ErrorMessage.gateway_timeout/2","type":"function"},{"doc":"Create gone error message for status code 410 Example iex&gt; ErrorMessage . gone ( &quot;error message&quot; ) % ErrorMessage { code : :gone , message : &quot;error message&quot; }","ref":"ErrorMessage.html#gone/1","title":"ErrorMessage.gone/1","type":"function"},{"doc":"Create gone error message for status code 410 with a details item which is passed in as the details key under the ErrorMessage struct Example iex&gt; ErrorMessage . gone ( &quot;error message&quot; , %{ item : 1234 } ) % ErrorMessage { code : :gone , message : &quot;error message&quot; , details : %{ item : 1234 } }","ref":"ErrorMessage.html#gone/2","title":"ErrorMessage.gone/2","type":"function"},{"doc":"See Plug.Conn.Status.code/1 .","ref":"ErrorMessage.html#http_code/1","title":"ErrorMessage.http_code/1","type":"function"},{"doc":"Create http_version_not_supported error message for status code 505 Example iex&gt; ErrorMessage . http_version_not_supported ( &quot;error message&quot; ) % ErrorMessage { code : :http_version_not_supported , message : &quot;error message&quot; }","ref":"ErrorMessage.html#http_version_not_supported/1","title":"ErrorMessage.http_version_not_supported/1","type":"function"},{"doc":"Create http_version_not_supported error message for status code 505 with a details item which is passed in as the details key under the ErrorMessage struct Example iex&gt; ErrorMessage . http_version_not_supported ( &quot;error message&quot; , %{ item : 1234 } ) % ErrorMessage { code : :http_version_not_supported , message : &quot;error message&quot; , details : %{ item : 1234 } }","ref":"ErrorMessage.html#http_version_not_supported/2","title":"ErrorMessage.http_version_not_supported/2","type":"function"},{"doc":"Create im_a_teapot error message for status code 418 Example iex&gt; ErrorMessage . im_a_teapot ( &quot;error message&quot; ) % ErrorMessage { code : :im_a_teapot , message : &quot;error message&quot; }","ref":"ErrorMessage.html#im_a_teapot/1","title":"ErrorMessage.im_a_teapot/1","type":"function"},{"doc":"Create im_a_teapot error message for status code 418 with a details item which is passed in as the details key under the ErrorMessage struct Example iex&gt; ErrorMessage . im_a_teapot ( &quot;error message&quot; , %{ item : 1234 } ) % ErrorMessage { code : :im_a_teapot , message : &quot;error message&quot; , details : %{ item : 1234 } }","ref":"ErrorMessage.html#im_a_teapot/2","title":"ErrorMessage.im_a_teapot/2","type":"function"},{"doc":"Converts an %ErrorMessage{} struct into an inspectable version ## Example iex&gt; ErrorMessage . inspect ( ErrorMessage . not_found ( &quot;couldn&#39;t find user&quot; , %{ user_id : &quot;as21fasdfJ&quot; } ) ) &quot;#ErrorMessage&lt;code: :not_found, message: \\&quot; couldn&#39;t find user \\&quot; &gt; \\n Details: \\n %{user_id: \\&quot; as21fasdfJ \\&quot; }&quot;","ref":"ErrorMessage.html#inspect/1","title":"ErrorMessage.inspect/1","type":"function"},{"doc":"Create insufficient_storage error message for status code 507 Example iex&gt; ErrorMessage . insufficient_storage ( &quot;error message&quot; ) % ErrorMessage { code : :insufficient_storage , message : &quot;error message&quot; }","ref":"ErrorMessage.html#insufficient_storage/1","title":"ErrorMessage.insufficient_storage/1","type":"function"},{"doc":"Create insufficient_storage error message for status code 507 with a details item which is passed in as the details key under the ErrorMessage struct Example iex&gt; ErrorMessage . insufficient_storage ( &quot;error message&quot; , %{ item : 1234 } ) % ErrorMessage { code : :insufficient_storage , message : &quot;error message&quot; , details : %{ item : 1234 } }","ref":"ErrorMessage.html#insufficient_storage/2","title":"ErrorMessage.insufficient_storage/2","type":"function"},{"doc":"Create internal_server_error error message for status code 500 Example iex&gt; ErrorMessage . internal_server_error ( &quot;error message&quot; ) % ErrorMessage { code : :internal_server_error , message : &quot;error message&quot; }","ref":"ErrorMessage.html#internal_server_error/1","title":"ErrorMessage.internal_server_error/1","type":"function"},{"doc":"Create internal_server_error error message for status code 500 with a details item which is passed in as the details key under the ErrorMessage struct Example iex&gt; ErrorMessage . internal_server_error ( &quot;error message&quot; , %{ item : 1234 } ) % ErrorMessage { code : :internal_server_error , message : &quot;error message&quot; , details : %{ item : 1234 } }","ref":"ErrorMessage.html#internal_server_error/2","title":"ErrorMessage.internal_server_error/2","type":"function"},{"doc":"Create length_required error message for status code 411 Example iex&gt; ErrorMessage . length_required ( &quot;error message&quot; ) % ErrorMessage { code : :length_required , message : &quot;error message&quot; }","ref":"ErrorMessage.html#length_required/1","title":"ErrorMessage.length_required/1","type":"function"},{"doc":"Create length_required error message for status code 411 with a details item which is passed in as the details key under the ErrorMessage struct Example iex&gt; ErrorMessage . length_required ( &quot;error message&quot; , %{ item : 1234 } ) % ErrorMessage { code : :length_required , message : &quot;error message&quot; , details : %{ item : 1234 } }","ref":"ErrorMessage.html#length_required/2","title":"ErrorMessage.length_required/2","type":"function"},{"doc":"Create locked error message for status code 423 Example iex&gt; ErrorMessage . locked ( &quot;error message&quot; ) % ErrorMessage { code : :locked , message : &quot;error message&quot; }","ref":"ErrorMessage.html#locked/1","title":"ErrorMessage.locked/1","type":"function"},{"doc":"Create locked error message for status code 423 with a details item which is passed in as the details key under the ErrorMessage struct Example iex&gt; ErrorMessage . locked ( &quot;error message&quot; , %{ item : 1234 } ) % ErrorMessage { code : :locked , message : &quot;error message&quot; , details : %{ item : 1234 } }","ref":"ErrorMessage.html#locked/2","title":"ErrorMessage.locked/2","type":"function"},{"doc":"Create loop_detected error message for status code 508 Example iex&gt; ErrorMessage . loop_detected ( &quot;error message&quot; ) % ErrorMessage { code : :loop_detected , message : &quot;error message&quot; }","ref":"ErrorMessage.html#loop_detected/1","title":"ErrorMessage.loop_detected/1","type":"function"},{"doc":"Create loop_detected error message for status code 508 with a details item which is passed in as the details key under the ErrorMessage struct Example iex&gt; ErrorMessage . loop_detected ( &quot;error message&quot; , %{ item : 1234 } ) % ErrorMessage { code : :loop_detected , message : &quot;error message&quot; , details : %{ item : 1234 } }","ref":"ErrorMessage.html#loop_detected/2","title":"ErrorMessage.loop_detected/2","type":"function"},{"doc":"Create method_not_allowed error message for status code 405 Example iex&gt; ErrorMessage . method_not_allowed ( &quot;error message&quot; ) % ErrorMessage { code : :method_not_allowed , message : &quot;error message&quot; }","ref":"ErrorMessage.html#method_not_allowed/1","title":"ErrorMessage.method_not_allowed/1","type":"function"},{"doc":"Create method_not_allowed error message for status code 405 with a details item which is passed in as the details key under the ErrorMessage struct Example iex&gt; ErrorMessage . method_not_allowed ( &quot;error message&quot; , %{ item : 1234 } ) % ErrorMessage { code : :method_not_allowed , message : &quot;error message&quot; , details : %{ item : 1234 } }","ref":"ErrorMessage.html#method_not_allowed/2","title":"ErrorMessage.method_not_allowed/2","type":"function"},{"doc":"Create misdirected_request error message for status code 421 Example iex&gt; ErrorMessage . misdirected_request ( &quot;error message&quot; ) % ErrorMessage { code : :misdirected_request , message : &quot;error message&quot; }","ref":"ErrorMessage.html#misdirected_request/1","title":"ErrorMessage.misdirected_request/1","type":"function"},{"doc":"Create misdirected_request error message for status code 421 with a details item which is passed in as the details key under the ErrorMessage struct Example iex&gt; ErrorMessage . misdirected_request ( &quot;error message&quot; , %{ item : 1234 } ) % ErrorMessage { code : :misdirected_request , message : &quot;error message&quot; , details : %{ item : 1234 } }","ref":"ErrorMessage.html#misdirected_request/2","title":"ErrorMessage.misdirected_request/2","type":"function"},{"doc":"Create moved_permanently error message for status code 301 Example iex&gt; ErrorMessage . moved_permanently ( &quot;error message&quot; ) % ErrorMessage { code : :moved_permanently , message : &quot;error message&quot; }","ref":"ErrorMessage.html#moved_permanently/1","title":"ErrorMessage.moved_permanently/1","type":"function"},{"doc":"Create moved_permanently error message for status code 301 with a details item which is passed in as the details key under the ErrorMessage struct Example iex&gt; ErrorMessage . moved_permanently ( &quot;error message&quot; , %{ item : 1234 } ) % ErrorMessage { code : :moved_permanently , message : &quot;error message&quot; , details : %{ item : 1234 } }","ref":"ErrorMessage.html#moved_permanently/2","title":"ErrorMessage.moved_permanently/2","type":"function"},{"doc":"Create multiple_choices error message for status code 300 Example iex&gt; ErrorMessage . multiple_choices ( &quot;error message&quot; ) % ErrorMessage { code : :multiple_choices , message : &quot;error message&quot; }","ref":"ErrorMessage.html#multiple_choices/1","title":"ErrorMessage.multiple_choices/1","type":"function"},{"doc":"Create multiple_choices error message for status code 300 with a details item which is passed in as the details key under the ErrorMessage struct Example iex&gt; ErrorMessage . multiple_choices ( &quot;error message&quot; , %{ item : 1234 } ) % ErrorMessage { code : :multiple_choices , message : &quot;error message&quot; , details : %{ item : 1234 } }","ref":"ErrorMessage.html#multiple_choices/2","title":"ErrorMessage.multiple_choices/2","type":"function"},{"doc":"Create network_authentication_required error message for status code 511 Example iex&gt; ErrorMessage . network_authentication_required ( &quot;error message&quot; ) % ErrorMessage { code : :network_authentication_required , message : &quot;error message&quot; }","ref":"ErrorMessage.html#network_authentication_required/1","title":"ErrorMessage.network_authentication_required/1","type":"function"},{"doc":"Create network_authentication_required error message for status code 511 with a details item which is passed in as the details key under the ErrorMessage struct Example iex&gt; ErrorMessage . network_authentication_required ( &quot;error message&quot; , %{ item : 1234 } ) % ErrorMessage { code : :network_authentication_required , message : &quot;error message&quot; , details : %{ item : 1234 } }","ref":"ErrorMessage.html#network_authentication_required/2","title":"ErrorMessage.network_authentication_required/2","type":"function"},{"doc":"Create not_acceptable error message for status code 406 Example iex&gt; ErrorMessage . not_acceptable ( &quot;error message&quot; ) % ErrorMessage { code : :not_acceptable , message : &quot;error message&quot; }","ref":"ErrorMessage.html#not_acceptable/1","title":"ErrorMessage.not_acceptable/1","type":"function"},{"doc":"Create not_acceptable error message for status code 406 with a details item which is passed in as the details key under the ErrorMessage struct Example iex&gt; ErrorMessage . not_acceptable ( &quot;error message&quot; , %{ item : 1234 } ) % ErrorMessage { code : :not_acceptable , message : &quot;error message&quot; , details : %{ item : 1234 } }","ref":"ErrorMessage.html#not_acceptable/2","title":"ErrorMessage.not_acceptable/2","type":"function"},{"doc":"Create not_extended error message for status code 510 Example iex&gt; ErrorMessage . not_extended ( &quot;error message&quot; ) % ErrorMessage { code : :not_extended , message : &quot;error message&quot; }","ref":"ErrorMessage.html#not_extended/1","title":"ErrorMessage.not_extended/1","type":"function"},{"doc":"Create not_extended error message for status code 510 with a details item which is passed in as the details key under the ErrorMessage struct Example iex&gt; ErrorMessage . not_extended ( &quot;error message&quot; , %{ item : 1234 } ) % ErrorMessage { code : :not_extended , message : &quot;error message&quot; , details : %{ item : 1234 } }","ref":"ErrorMessage.html#not_extended/2","title":"ErrorMessage.not_extended/2","type":"function"},{"doc":"Create not_found error message for status code 404 Example iex&gt; ErrorMessage . not_found ( &quot;error message&quot; ) % ErrorMessage { code : :not_found , message : &quot;error message&quot; }","ref":"ErrorMessage.html#not_found/1","title":"ErrorMessage.not_found/1","type":"function"},{"doc":"Create not_found error message for status code 404 with a details item which is passed in as the details key under the ErrorMessage struct Example iex&gt; ErrorMessage . not_found ( &quot;error message&quot; , %{ item : 1234 } ) % ErrorMessage { code : :not_found , message : &quot;error message&quot; , details : %{ item : 1234 } }","ref":"ErrorMessage.html#not_found/2","title":"ErrorMessage.not_found/2","type":"function"},{"doc":"Create not_implemented error message for status code 501 Example iex&gt; ErrorMessage . not_implemented ( &quot;error message&quot; ) % ErrorMessage { code : :not_implemented , message : &quot;error message&quot; }","ref":"ErrorMessage.html#not_implemented/1","title":"ErrorMessage.not_implemented/1","type":"function"},{"doc":"Create not_implemented error message for status code 501 with a details item which is passed in as the details key under the ErrorMessage struct Example iex&gt; ErrorMessage . not_implemented ( &quot;error message&quot; , %{ item : 1234 } ) % ErrorMessage { code : :not_implemented , message : &quot;error message&quot; , details : %{ item : 1234 } }","ref":"ErrorMessage.html#not_implemented/2","title":"ErrorMessage.not_implemented/2","type":"function"},{"doc":"Create not_modified error message for status code 304 Example iex&gt; ErrorMessage . not_modified ( &quot;error message&quot; ) % ErrorMessage { code : :not_modified , message : &quot;error message&quot; }","ref":"ErrorMessage.html#not_modified/1","title":"ErrorMessage.not_modified/1","type":"function"},{"doc":"Create not_modified error message for status code 304 with a details item which is passed in as the details key under the ErrorMessage struct Example iex&gt; ErrorMessage . not_modified ( &quot;error message&quot; , %{ item : 1234 } ) % ErrorMessage { code : :not_modified , message : &quot;error message&quot; , details : %{ item : 1234 } }","ref":"ErrorMessage.html#not_modified/2","title":"ErrorMessage.not_modified/2","type":"function"},{"doc":"Create payment_required error message for status code 402 Example iex&gt; ErrorMessage . payment_required ( &quot;error message&quot; ) % ErrorMessage { code : :payment_required , message : &quot;error message&quot; }","ref":"ErrorMessage.html#payment_required/1","title":"ErrorMessage.payment_required/1","type":"function"},{"doc":"Create payment_required error message for status code 402 with a details item which is passed in as the details key under the ErrorMessage struct Example iex&gt; ErrorMessage . payment_required ( &quot;error message&quot; , %{ item : 1234 } ) % ErrorMessage { code : :payment_required , message : &quot;error message&quot; , details : %{ item : 1234 } }","ref":"ErrorMessage.html#payment_required/2","title":"ErrorMessage.payment_required/2","type":"function"},{"doc":"Create permanent_redirect error message for status code 308 Example iex&gt; ErrorMessage . permanent_redirect ( &quot;error message&quot; ) % ErrorMessage { code : :permanent_redirect , message : &quot;error message&quot; }","ref":"ErrorMessage.html#permanent_redirect/1","title":"ErrorMessage.permanent_redirect/1","type":"function"},{"doc":"Create permanent_redirect error message for status code 308 with a details item which is passed in as the details key under the ErrorMessage struct Example iex&gt; ErrorMessage . permanent_redirect ( &quot;error message&quot; , %{ item : 1234 } ) % ErrorMessage { code : :permanent_redirect , message : &quot;error message&quot; , details : %{ item : 1234 } }","ref":"ErrorMessage.html#permanent_redirect/2","title":"ErrorMessage.permanent_redirect/2","type":"function"},{"doc":"Create precondition_failed error message for status code 412 Example iex&gt; ErrorMessage . precondition_failed ( &quot;error message&quot; ) % ErrorMessage { code : :precondition_failed , message : &quot;error message&quot; }","ref":"ErrorMessage.html#precondition_failed/1","title":"ErrorMessage.precondition_failed/1","type":"function"},{"doc":"Create precondition_failed error message for status code 412 with a details item which is passed in as the details key under the ErrorMessage struct Example iex&gt; ErrorMessage . precondition_failed ( &quot;error message&quot; , %{ item : 1234 } ) % ErrorMessage { code : :precondition_failed , message : &quot;error message&quot; , details : %{ item : 1234 } }","ref":"ErrorMessage.html#precondition_failed/2","title":"ErrorMessage.precondition_failed/2","type":"function"},{"doc":"Create precondition_required error message for status code 428 Example iex&gt; ErrorMessage . precondition_required ( &quot;error message&quot; ) % ErrorMessage { code : :precondition_required , message : &quot;error message&quot; }","ref":"ErrorMessage.html#precondition_required/1","title":"ErrorMessage.precondition_required/1","type":"function"},{"doc":"Create precondition_required error message for status code 428 with a details item which is passed in as the details key under the ErrorMessage struct Example iex&gt; ErrorMessage . precondition_required ( &quot;error message&quot; , %{ item : 1234 } ) % ErrorMessage { code : :precondition_required , message : &quot;error message&quot; , details : %{ item : 1234 } }","ref":"ErrorMessage.html#precondition_required/2","title":"ErrorMessage.precondition_required/2","type":"function"},{"doc":"Create proxy_authentication_required error message for status code 407 Example iex&gt; ErrorMessage . proxy_authentication_required ( &quot;error message&quot; ) % ErrorMessage { code : :proxy_authentication_required , message : &quot;error message&quot; }","ref":"ErrorMessage.html#proxy_authentication_required/1","title":"ErrorMessage.proxy_authentication_required/1","type":"function"},{"doc":"Create proxy_authentication_required error message for status code 407 with a details item which is passed in as the details key under the ErrorMessage struct Example iex&gt; ErrorMessage . proxy_authentication_required ( &quot;error message&quot; , %{ item : 1234 } ) % ErrorMessage { code : :proxy_authentication_required , message : &quot;error message&quot; , details : %{ item : 1234 } }","ref":"ErrorMessage.html#proxy_authentication_required/2","title":"ErrorMessage.proxy_authentication_required/2","type":"function"},{"doc":"Create request_entity_too_large error message for status code 413 Example iex&gt; ErrorMessage . request_entity_too_large ( &quot;error message&quot; ) % ErrorMessage { code : :request_entity_too_large , message : &quot;error message&quot; }","ref":"ErrorMessage.html#request_entity_too_large/1","title":"ErrorMessage.request_entity_too_large/1","type":"function"},{"doc":"Create request_entity_too_large error message for status code 413 with a details item which is passed in as the details key under the ErrorMessage struct Example iex&gt; ErrorMessage . request_entity_too_large ( &quot;error message&quot; , %{ item : 1234 } ) % ErrorMessage { code : :request_entity_too_large , message : &quot;error message&quot; , details : %{ item : 1234 } }","ref":"ErrorMessage.html#request_entity_too_large/2","title":"ErrorMessage.request_entity_too_large/2","type":"function"},{"doc":"Create request_header_fields_too_large error message for status code 431 Example iex&gt; ErrorMessage . request_header_fields_too_large ( &quot;error message&quot; ) % ErrorMessage { code : :request_header_fields_too_large , message : &quot;error message&quot; }","ref":"ErrorMessage.html#request_header_fields_too_large/1","title":"ErrorMessage.request_header_fields_too_large/1","type":"function"},{"doc":"Create request_header_fields_too_large error message for status code 431 with a details item which is passed in as the details key under the ErrorMessage struct Example iex&gt; ErrorMessage . request_header_fields_too_large ( &quot;error message&quot; , %{ item : 1234 } ) % ErrorMessage { code : :request_header_fields_too_large , message : &quot;error message&quot; , details : %{ item : 1234 } }","ref":"ErrorMessage.html#request_header_fields_too_large/2","title":"ErrorMessage.request_header_fields_too_large/2","type":"function"},{"doc":"Create request_timeout error message for status code 408 Example iex&gt; ErrorMessage . request_timeout ( &quot;error message&quot; ) % ErrorMessage { code : :request_timeout , message : &quot;error message&quot; }","ref":"ErrorMessage.html#request_timeout/1","title":"ErrorMessage.request_timeout/1","type":"function"},{"doc":"Create request_timeout error message for status code 408 with a details item which is passed in as the details key under the ErrorMessage struct Example iex&gt; ErrorMessage . request_timeout ( &quot;error message&quot; , %{ item : 1234 } ) % ErrorMessage { code : :request_timeout , message : &quot;error message&quot; , details : %{ item : 1234 } }","ref":"ErrorMessage.html#request_timeout/2","title":"ErrorMessage.request_timeout/2","type":"function"},{"doc":"Create request_uri_too_long error message for status code 414 Example iex&gt; ErrorMessage . request_uri_too_long ( &quot;error message&quot; ) % ErrorMessage { code : :request_uri_too_long , message : &quot;error message&quot; }","ref":"ErrorMessage.html#request_uri_too_long/1","title":"ErrorMessage.request_uri_too_long/1","type":"function"},{"doc":"Create request_uri_too_long error message for status code 414 with a details item which is passed in as the details key under the ErrorMessage struct Example iex&gt; ErrorMessage . request_uri_too_long ( &quot;error message&quot; , %{ item : 1234 } ) % ErrorMessage { code : :request_uri_too_long , message : &quot;error message&quot; , details : %{ item : 1234 } }","ref":"ErrorMessage.html#request_uri_too_long/2","title":"ErrorMessage.request_uri_too_long/2","type":"function"},{"doc":"Create requested_range_not_satisfiable error message for status code 416 Example iex&gt; ErrorMessage . requested_range_not_satisfiable ( &quot;error message&quot; ) % ErrorMessage { code : :requested_range_not_satisfiable , message : &quot;error message&quot; }","ref":"ErrorMessage.html#requested_range_not_satisfiable/1","title":"ErrorMessage.requested_range_not_satisfiable/1","type":"function"},{"doc":"Create requested_range_not_satisfiable error message for status code 416 with a details item which is passed in as the details key under the ErrorMessage struct Example iex&gt; ErrorMessage . requested_range_not_satisfiable ( &quot;error message&quot; , %{ item : 1234 } ) % ErrorMessage { code : :requested_range_not_satisfiable , message : &quot;error message&quot; , details : %{ item : 1234 } }","ref":"ErrorMessage.html#requested_range_not_satisfiable/2","title":"ErrorMessage.requested_range_not_satisfiable/2","type":"function"},{"doc":"Create see_other error message for status code 303 Example iex&gt; ErrorMessage . see_other ( &quot;error message&quot; ) % ErrorMessage { code : :see_other , message : &quot;error message&quot; }","ref":"ErrorMessage.html#see_other/1","title":"ErrorMessage.see_other/1","type":"function"},{"doc":"Create see_other error message for status code 303 with a details item which is passed in as the details key under the ErrorMessage struct Example iex&gt; ErrorMessage . see_other ( &quot;error message&quot; , %{ item : 1234 } ) % ErrorMessage { code : :see_other , message : &quot;error message&quot; , details : %{ item : 1234 } }","ref":"ErrorMessage.html#see_other/2","title":"ErrorMessage.see_other/2","type":"function"},{"doc":"Create service_unavailable error message for status code 503 Example iex&gt; ErrorMessage . service_unavailable ( &quot;error message&quot; ) % ErrorMessage { code : :service_unavailable , message : &quot;error message&quot; }","ref":"ErrorMessage.html#service_unavailable/1","title":"ErrorMessage.service_unavailable/1","type":"function"},{"doc":"Create service_unavailable error message for status code 503 with a details item which is passed in as the details key under the ErrorMessage struct Example iex&gt; ErrorMessage . service_unavailable ( &quot;error message&quot; , %{ item : 1234 } ) % ErrorMessage { code : :service_unavailable , message : &quot;error message&quot; , details : %{ item : 1234 } }","ref":"ErrorMessage.html#service_unavailable/2","title":"ErrorMessage.service_unavailable/2","type":"function"},{"doc":"Create switch_proxy error message for status code 306 Example iex&gt; ErrorMessage . switch_proxy ( &quot;error message&quot; ) % ErrorMessage { code : :switch_proxy , message : &quot;error message&quot; }","ref":"ErrorMessage.html#switch_proxy/1","title":"ErrorMessage.switch_proxy/1","type":"function"},{"doc":"Create switch_proxy error message for status code 306 with a details item which is passed in as the details key under the ErrorMessage struct Example iex&gt; ErrorMessage . switch_proxy ( &quot;error message&quot; , %{ item : 1234 } ) % ErrorMessage { code : :switch_proxy , message : &quot;error message&quot; , details : %{ item : 1234 } }","ref":"ErrorMessage.html#switch_proxy/2","title":"ErrorMessage.switch_proxy/2","type":"function"},{"doc":"Create temporary_redirect error message for status code 307 Example iex&gt; ErrorMessage . temporary_redirect ( &quot;error message&quot; ) % ErrorMessage { code : :temporary_redirect , message : &quot;error message&quot; }","ref":"ErrorMessage.html#temporary_redirect/1","title":"ErrorMessage.temporary_redirect/1","type":"function"},{"doc":"Create temporary_redirect error message for status code 307 with a details item which is passed in as the details key under the ErrorMessage struct Example iex&gt; ErrorMessage . temporary_redirect ( &quot;error message&quot; , %{ item : 1234 } ) % ErrorMessage { code : :temporary_redirect , message : &quot;error message&quot; , details : %{ item : 1234 } }","ref":"ErrorMessage.html#temporary_redirect/2","title":"ErrorMessage.temporary_redirect/2","type":"function"},{"doc":"Converts an %ErrorMessage{} struct to a map and makes sure that the contents of the details map can be converted to json ## Example iex&gt; ErrorMessage . to_jsonable_map ( ErrorMessage . not_found ( &quot;couldn&#39;t find user&quot; , %{ user_id : &quot;as21fasdfJ&quot; } ) ) %{ code : :not_found , message : &quot;couldn&#39;t find user&quot; , details : %{ user_id : &quot;as21fasdfJ&quot; } } iex&gt; error = ErrorMessage . im_a_teapot ( &quot;teapot&quot; , %{ ...&gt; user : %{ health : { :alive , 500 } } , ...&gt; test : % TestStruct { a : [ Date . new! ( 2020 , 1 , 10 ) ] } ...&gt; } ) iex&gt; ErrorMessage . to_jsonable_map ( error ) %{ code : :im_a_teapot , message : &quot;teapot&quot; , details : %{ user : %{ health : [ :alive , 500 ] } , test : %{ struct : &quot;ErrorMessageTest.TestStruct&quot; , data : %{ a : [ &quot;2020-01-10&quot; ] } } } }","ref":"ErrorMessage.html#to_jsonable_map/1","title":"ErrorMessage.to_jsonable_map/1","type":"function"},{"doc":"Converts an %ErrorMessage{} struct to a string formatted error message ## Example iex&gt; ErrorMessage . to_string ( ErrorMessage . internal_server_error ( &quot;Something bad happened&quot; , %{ result : :unknown } ) ) &quot;internal_server_error - Something bad happened \\n Details: \\n %{result: :unknown}&quot;","ref":"ErrorMessage.html#to_string/1","title":"ErrorMessage.to_string/1","type":"function"},{"doc":"Create too_early error message for status code 425 Example iex&gt; ErrorMessage . too_early ( &quot;error message&quot; ) % ErrorMessage { code : :too_early , message : &quot;error message&quot; }","ref":"ErrorMessage.html#too_early/1","title":"ErrorMessage.too_early/1","type":"function"},{"doc":"Create too_early error message for status code 425 with a details item which is passed in as the details key under the ErrorMessage struct Example iex&gt; ErrorMessage . too_early ( &quot;error message&quot; , %{ item : 1234 } ) % ErrorMessage { code : :too_early , message : &quot;error message&quot; , details : %{ item : 1234 } }","ref":"ErrorMessage.html#too_early/2","title":"ErrorMessage.too_early/2","type":"function"},{"doc":"Create too_many_requests error message for status code 429 Example iex&gt; ErrorMessage . too_many_requests ( &quot;error message&quot; ) % ErrorMessage { code : :too_many_requests , message : &quot;error message&quot; }","ref":"ErrorMessage.html#too_many_requests/1","title":"ErrorMessage.too_many_requests/1","type":"function"},{"doc":"Create too_many_requests error message for status code 429 with a details item which is passed in as the details key under the ErrorMessage struct Example iex&gt; ErrorMessage . too_many_requests ( &quot;error message&quot; , %{ item : 1234 } ) % ErrorMessage { code : :too_many_requests , message : &quot;error message&quot; , details : %{ item : 1234 } }","ref":"ErrorMessage.html#too_many_requests/2","title":"ErrorMessage.too_many_requests/2","type":"function"},{"doc":"Create unauthorized error message for status code 401 Example iex&gt; ErrorMessage . unauthorized ( &quot;error message&quot; ) % ErrorMessage { code : :unauthorized , message : &quot;error message&quot; }","ref":"ErrorMessage.html#unauthorized/1","title":"ErrorMessage.unauthorized/1","type":"function"},{"doc":"Create unauthorized error message for status code 401 with a details item which is passed in as the details key under the ErrorMessage struct Example iex&gt; ErrorMessage . unauthorized ( &quot;error message&quot; , %{ item : 1234 } ) % ErrorMessage { code : :unauthorized , message : &quot;error message&quot; , details : %{ item : 1234 } }","ref":"ErrorMessage.html#unauthorized/2","title":"ErrorMessage.unauthorized/2","type":"function"},{"doc":"Create unavailable_for_legal_reasons error message for status code 451 Example iex&gt; ErrorMessage . unavailable_for_legal_reasons ( &quot;error message&quot; ) % ErrorMessage { code : :unavailable_for_legal_reasons , message : &quot;error message&quot; }","ref":"ErrorMessage.html#unavailable_for_legal_reasons/1","title":"ErrorMessage.unavailable_for_legal_reasons/1","type":"function"},{"doc":"Create unavailable_for_legal_reasons error message for status code 451 with a details item which is passed in as the details key under the ErrorMessage struct Example iex&gt; ErrorMessage . unavailable_for_legal_reasons ( &quot;error message&quot; , %{ item : 1234 } ) % ErrorMessage { code : :unavailable_for_legal_reasons , message : &quot;error message&quot; , details : %{ item : 1234 } }","ref":"ErrorMessage.html#unavailable_for_legal_reasons/2","title":"ErrorMessage.unavailable_for_legal_reasons/2","type":"function"},{"doc":"Create unprocessable_entity error message for status code 422 Example iex&gt; ErrorMessage . unprocessable_entity ( &quot;error message&quot; ) % ErrorMessage { code : :unprocessable_entity , message : &quot;error message&quot; }","ref":"ErrorMessage.html#unprocessable_entity/1","title":"ErrorMessage.unprocessable_entity/1","type":"function"},{"doc":"Create unprocessable_entity error message for status code 422 with a details item which is passed in as the details key under the ErrorMessage struct Example iex&gt; ErrorMessage . unprocessable_entity ( &quot;error message&quot; , %{ item : 1234 } ) % ErrorMessage { code : :unprocessable_entity , message : &quot;error message&quot; , details : %{ item : 1234 } }","ref":"ErrorMessage.html#unprocessable_entity/2","title":"ErrorMessage.unprocessable_entity/2","type":"function"},{"doc":"Create unsupported_media_type error message for status code 415 Example iex&gt; ErrorMessage . unsupported_media_type ( &quot;error message&quot; ) % ErrorMessage { code : :unsupported_media_type , message : &quot;error message&quot; }","ref":"ErrorMessage.html#unsupported_media_type/1","title":"ErrorMessage.unsupported_media_type/1","type":"function"},{"doc":"Create unsupported_media_type error message for status code 415 with a details item which is passed in as the details key under the ErrorMessage struct Example iex&gt; ErrorMessage . unsupported_media_type ( &quot;error message&quot; , %{ item : 1234 } ) % ErrorMessage { code : :unsupported_media_type , message : &quot;error message&quot; , details : %{ item : 1234 } }","ref":"ErrorMessage.html#unsupported_media_type/2","title":"ErrorMessage.unsupported_media_type/2","type":"function"},{"doc":"Create upgrade_required error message for status code 426 Example iex&gt; ErrorMessage . upgrade_required ( &quot;error message&quot; ) % ErrorMessage { code : :upgrade_required , message : &quot;error message&quot; }","ref":"ErrorMessage.html#upgrade_required/1","title":"ErrorMessage.upgrade_required/1","type":"function"},{"doc":"Create upgrade_required error message for status code 426 with a details item which is passed in as the details key under the ErrorMessage struct Example iex&gt; ErrorMessage . upgrade_required ( &quot;error message&quot; , %{ item : 1234 } ) % ErrorMessage { code : :upgrade_required , message : &quot;error message&quot; , details : %{ item : 1234 } }","ref":"ErrorMessage.html#upgrade_required/2","title":"ErrorMessage.upgrade_required/2","type":"function"},{"doc":"Create use_proxy error message for status code 305 Example iex&gt; ErrorMessage . use_proxy ( &quot;error message&quot; ) % ErrorMessage { code : :use_proxy , message : &quot;error message&quot; }","ref":"ErrorMessage.html#use_proxy/1","title":"ErrorMessage.use_proxy/1","type":"function"},{"doc":"Create use_proxy error message for status code 305 with a details item which is passed in as the details key under the ErrorMessage struct Example iex&gt; ErrorMessage . use_proxy ( &quot;error message&quot; , %{ item : 1234 } ) % ErrorMessage { code : :use_proxy , message : &quot;error message&quot; , details : %{ item : 1234 } }","ref":"ErrorMessage.html#use_proxy/2","title":"ErrorMessage.use_proxy/2","type":"function"},{"doc":"Create variant_also_negotiates error message for status code 506 Example iex&gt; ErrorMessage . variant_also_negotiates ( &quot;error message&quot; ) % ErrorMessage { code : :variant_also_negotiates , message : &quot;error message&quot; }","ref":"ErrorMessage.html#variant_also_negotiates/1","title":"ErrorMessage.variant_also_negotiates/1","type":"function"},{"doc":"Create variant_also_negotiates error message for status code 506 with a details item which is passed in as the details key under the ErrorMessage struct Example iex&gt; ErrorMessage . variant_also_negotiates ( &quot;error message&quot; , %{ item : 1234 } ) % ErrorMessage { code : :variant_also_negotiates , message : &quot;error message&quot; , details : %{ item : 1234 } }","ref":"ErrorMessage.html#variant_also_negotiates/2","title":"ErrorMessage.variant_also_negotiates/2","type":"function"},{"doc":"","ref":"ErrorMessage.html#t:code/0","title":"ErrorMessage.code/0","type":"type"},{"doc":"","ref":"ErrorMessage.html#t:t/0","title":"ErrorMessage.t/0","type":"type"},{"doc":"","ref":"ErrorMessage.html#t:t/1","title":"ErrorMessage.t/1","type":"type"},{"doc":"","ref":"ErrorMessage.html#t:t_map/0","title":"ErrorMessage.t_map/0","type":"type"},{"doc":"","ref":"ErrorMessage.html#t:t_map/1","title":"ErrorMessage.t_map/1","type":"type"},{"doc":"","ref":"ErrorMessage.html#t:t_res/0","title":"ErrorMessage.t_res/0","type":"type"},{"doc":"","ref":"ErrorMessage.html#t:t_res/1","title":"ErrorMessage.t_res/1","type":"type"},{"doc":"","ref":"ErrorMessage.html#t:t_res/2","title":"ErrorMessage.t_res/2","type":"type"}]